@@ -8,4 +8,8 @@ def assetpath(p:str)->os.path:
     return posixpath.join(ASSETS,p)
 STATIC = "static"
 def staticpath(p:str)->os.path:
-    return posixpath.join(STATIC,p)
\ No newline at end of file
+    return posixpath.join(STATIC,p)
+
+DEBUG = ".debug"
+def debugpath(p:str)->os.path:
+    return posixpath.join(DEBUG,p)
\ No newline at end of file
